==> bolter_flutter-6.7.2.tar.gz: lib/src/sync_builder.dart <==
part of 'bolter_provider.dart';

class SyncBuilderController {
  final BolterInterface bolter;
  late BolterNotification? _notification;

  SyncBuilderController(this.bolter);

  void update(BolterNotification action) =>
      bolter.runAndUpdate(exactNotification: _notification, action: action);

  void dispose(){
    _notification = null;
  }
}

class SyncBuilder<T> extends StatefulWidget {
  final T Function() getter;
  final WidgetBuilder builder;
  final SyncBuilderController? controller;

  const SyncBuilder({
    Key? key,
    required this.getter,
    required this.builder,
    this.controller,
  }) : super(key: key);

  @override
  _SyncBuilderState<T> createState() => _SyncBuilderState<T>();
}

class _SyncBuilderState<T> extends State<SyncBuilder<T>> {
  late final bolter =
      context.findAncestorWidgetOfExactType<BolterProvider>()?.bolter ?? defaultBolter;

  void _notification() {
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    widget.controller?._notification = _notification;
    bolter.listen(widget.getter, _notification);
  }

  @override
  void didUpdateWidget(SyncBuilder<T> oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.getter != widget.getter) {
      bolter.stopListen(_notification);
      bolter.listen(widget.getter, _notification);
    }
  }

  @override
  Widget build(BuildContext context) {
    return widget.builder(context);
  }

  @override
  void dispose() {
    bolter.stopListen(_notification);
    widget.controller?.dispose();
    super.dispose();
  }
}

==> bolter_flutter-6.7.3.tar.gz: lib/src/sync_builder.dart <==
part of 'bolter_provider.dart';

class SyncBuilderController {
  final BolterInterface bolter;
  BolterNotification? _notification;

  SyncBuilderController(this.bolter);

  void update(BolterNotification action) {
    bolter.runAndUpdate(exactNotification: _notification, action: action);
  }

  void dispose(){
    _notification = null;
  }
}

class SyncBuilder<T> extends StatefulWidget {
  final T Function() getter;
  final WidgetBuilder builder;
  final SyncBuilderController? controller;

  const SyncBuilder({
    Key? key,
    required this.getter,
    required this.builder,
    this.controller,
  }) : super(key: key);

  @override
  _SyncBuilderState<T> createState() => _SyncBuilderState<T>();
}

class _SyncBuilderState<T> extends State<SyncBuilder<T>> {
  late final bolter =
      context.findAncestorWidgetOfExactType<BolterProvider>()?.bolter ?? defaultBolter;

  void _notification() {
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    widget.controller?._notification = _notification;
    bolter.listen(widget.getter, _notification);
  }

  @override
  void didUpdateWidget(SyncBuilder<T> oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.getter != widget.getter) {
      bolter.stopListen(_notification);
      bolter.listen(widget.getter, _notification);
    }
  }

  @override
  Widget build(BuildContext context) {
    return widget.builder(context);
  }

  @override
  void dispose() {
    bolter.stopListen(_notification);
    widget.controller?.dispose();
    super.dispose();
  }
}
